summaryrefslogtreecommitdiffstats
path: root/chrome/browser/profile.h
diff options
context:
space:
mode:
authorabarth@chromium.org <abarth@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-09-05 14:21:09 +0000
committerabarth@chromium.org <abarth@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-09-05 14:21:09 +0000
commit77f6fb43d125edea5fe8b76d663de95098baf1de (patch)
tree3d0edff4af0ca2e5aea5b4520cf31526b249036e /chrome/browser/profile.h
parent78d4c52c925f79756e5c1cc8ae1095cdf61f3745 (diff)
downloadchromium_src-77f6fb43d125edea5fe8b76d663de95098baf1de.zip
chromium_src-77f6fb43d125edea5fe8b76d663de95098baf1de.tar.gz
chromium_src-77f6fb43d125edea5fe8b76d663de95098baf1de.tar.bz2
Rename X-Force-TLS to Strict-Transport-Security.
Also, remove StrictTransportSecurity code from SSLPolicy because that code doesn't work. R=agl Review URL: http://codereview.chromium.org/198035 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@25577 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/profile.h')
-rw-r--r--chrome/browser/profile.h21
1 files changed, 12 insertions, 9 deletions
diff --git a/chrome/browser/profile.h b/chrome/browser/profile.h
index 97e747b..1769ec8 100644
--- a/chrome/browser/profile.h
+++ b/chrome/browser/profile.h
@@ -19,7 +19,7 @@
#include "chrome/common/notification_registrar.h"
namespace net {
-class ForceTLSState;
+class StrictTransportSecurityState;
class SSLConfigService;
}
class Blacklist;
@@ -34,7 +34,6 @@ class ExtensionProcessManager;
class ExtensionMessageService;
class ExtensionsService;
class FaviconService;
-class ForceTLSPersister;
class HistoryService;
class NavigationController;
class PasswordStore;
@@ -44,6 +43,7 @@ class SessionService;
class SpellChecker;
class SSLConfigServiceManager;
class SSLHostState;
+class StrictTransportSecurityPersister;
class SQLitePersistentCookieStore;
class TabRestoreService;
class TemplateURLFetcher;
@@ -155,10 +155,11 @@ class Profile {
// called.
virtual SSLHostState* GetSSLHostState() = 0;
- // Retrieves a pointer to the ForceTLSState associated with this profile.
- // The ForceTLSState is lazily created the first time that this method is
- // called.
- virtual net::ForceTLSState* GetForceTLSState() = 0;
+ // Retrieves a pointer to the StrictTransportSecurityState associated with
+ // this profile. The StrictTransportSecurityState is lazily created the
+ // first time that this method is called.
+ virtual net::StrictTransportSecurityState*
+ GetStrictTransportSecurityState() = 0;
// Retrieves a pointer to the FaviconService associated with this
// profile. The FaviconService is lazily created the first time
@@ -370,7 +371,7 @@ class ProfileImpl : public Profile,
virtual VisitedLinkMaster* GetVisitedLinkMaster();
virtual UserScriptMaster* GetUserScriptMaster();
virtual SSLHostState* GetSSLHostState();
- virtual net::ForceTLSState* GetForceTLSState();
+ virtual net::StrictTransportSecurityState* GetStrictTransportSecurityState();
virtual ExtensionsService* GetExtensionsService();
virtual ExtensionDevToolsManager* GetExtensionDevToolsManager();
virtual ExtensionProcessManager* GetExtensionProcessManager();
@@ -461,8 +462,10 @@ class ProfileImpl : public Profile,
scoped_ptr<ExtensionProcessManager> extension_process_manager_;
scoped_refptr<ExtensionMessageService> extension_message_service_;
scoped_ptr<SSLHostState> ssl_host_state_;
- scoped_refptr<net::ForceTLSState> force_tls_state_;
- scoped_refptr<ForceTLSPersister> force_tls_persister_;
+ scoped_refptr<net::StrictTransportSecurityState>
+ strict_transport_security_state_;
+ scoped_refptr<StrictTransportSecurityPersister>
+ strict_transport_security_persister_;
scoped_ptr<PrefService> prefs_;
scoped_refptr<ThumbnailStore> thumbnail_store_;
scoped_ptr<TemplateURLFetcher> template_url_fetcher_;